@@ -214,7 +214,7 @@ def plot6(x,y,ytot, k,eigvec,freq,n,Ruc,eigname,masses, max_Z):
     fig.savefig('plot6_'+str(np.round(k))+'_mode_'+str(n)+'.pdf')
     return ani
 
-def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
+def save_proj(x,y,ytot,convolution, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
     pgf_with_latex = {                      # setup matplotlib to use latex for output
 
     "pgf.texsystem": "pdflatex",        # change this if using xetex or lautex
@@ -249,21 +249,30 @@ def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
 
     }
     
+    mpl.rcParams.update(pgf_with_latex)
+
     name_current_dir = namedir+'/'+str(k)
     try:
         os.mkdir(name_current_dir)
     except FileExistsError:
         a = 1
+        
+    
 
-    mpl.rcParams.update(pgf_with_latex)
     plt.ioff()
+    
+# =============================================================================
+#   plot convolved to Gaussian
     fig,ax = plt.subplots()
+    if(max_Z > np.max(ytot.max()) or max_Z < 0.0):
+        a=1
+    else:
+        ax.set_ylim(bottom=-max_Z/10,top=max_Z)
     #graph2, = ax.plot(x,ytot,'--',label='k-point DOS', color='grey')
-    graph1, = ax.plot(x,y,label='mode-projected DOS', color='blue', alpha=0.7, linewidth=.5)
+    graph1, = ax.plot(x,y,label='mode-projected DOS', color='blue', alpha=0.3, linewidth=.5)
 
     ax.set_xlabel('Frequency [Thz]')
     ax.set_ylabel('DOS [kB T * ps]')
-#    fig.suptitle('Spectrum of mode n. '+str(n)+' kpoint '+str(k))
     
     ax1 = ax.twiny()
     ax1.set_xlabel('Frequency [cm$^{-1}$]')
@@ -271,40 +280,10 @@ def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
     ax1.set_xlim(-1*33.35641,25*33.35641)
     ax.set_xlim(left=-1,right=25)
 
-    
-    if(max_Z > np.max(ytot.max()) or max_Z < 0.0):
-        a=1
-    else:
-        ax.set_ylim(bottom=-max_Z/10,top=max_Z)
-    
-    
-#    print('Mode frequency: ', freq, '\n')
-#    print('Eigenvector components:')
-#    print(np.round(np.reshape(np.real(eigvec),(5,3)),2))
-#    print()
-#    print('Imaginary part:')
-#    print(np.round(np.reshape(np.imag(eigvec),(5,3)),2))
-#    print()
-#    print()
-
-    
-    xx = np.arange(x.min(), x.max(), 0.01)
-    graph4, = ax.plot(xx,lorentzian(xx,*params), linewidth=3, color='orange', label='Lorentzian')
-    omega0 = params[0]
-    gamma = params[2]
-    y_max = np.max(lorentzian(x,*params))
-    if not(np.isnan(y_max)): #exclude acoustic at Gamma
-        ax.text(omega0+gamma, y_max/2, 'width='+str(np.round(gamma,2)))
-        ax.axvline(x=omega0, linestyle=':', color='black')
-        #vline1 = ax.plot(np.repeat(omega0,100),np.linspace(0,y_max/2,100),':' ,c='grey')
-        #vline1 = ax.plot(np.repeat(omega0+gamma/2,100),np.linspace(0,y_max/2,100) ,c='orangered')
-        ax.axvspan(omega0-gamma/2, omega0+gamma/2, ymin=0, ymax=1, color='grey', alpha=0.2)
-    
-
-    
-      
-    graph3, = ax.plot(np.repeat(freq,100),np.linspace(0,y.max(),100), c='red', label='freq from dispersion')
-    plt.legend(handles=[graph1, graph3, graph4])
+    graph5, = ax.plot(x,convolution, color='green', linewidth=1, label='convolved')
+    ax.set_ylim(bottom=-.05*convolution.max(),top=convolution.max()*1.1)
+    graph3, = ax.plot(np.repeat(freq,100),np.linspace(0,y.max(),100), linewidth=1, c='red', label='freq from dispersion')
+    plt.legend(handles=[   graph3, graph5])
     
 #    plt.subplots_adjust(top=0.85)
 #    if(np.allclose(k,[0,0,0])):
@@ -319,8 +298,46 @@ def save_proj(x,y,ytot, k,Ruc, eigvec,freq,n,namedir,masses, params, max_Z):
 
     plt.tight_layout()
     fig.savefig(name_current_dir+'/proj_'+str(k)+'mode'+str(n)+'.pdf')
+# =============================================================================
+   
+# =============================================================================
+#   plot Lorentzian
+    fig1, ax = plt.subplots()
+    if(max_Z > np.max(ytot.max()) or max_Z < 0.0):
+        a=1
+    else:
+        ax.set_ylim(bottom=-max_Z/10,top=max_Z)
+    graph1, = ax.plot(x,y,label='mode-projected DOS', color='blue', alpha=0.5, linewidth=.5)
+    
+    xx = np.arange(x.min(), x.max(), 0.01)
+    graph4, = ax.plot(xx,lorentzian(xx,*params), linewidth=2, alpha=0.8, color='orange', label='Lorentzian')
+    
+    ax.set_xlabel('Frequency [Thz]')
+    ax.set_ylabel('DOS [kB T * ps]')
+    
+    ax1 = ax.twiny()
+    ax1.set_xlabel('Frequency [cm$^{-1}$]')
+    ax1.plot(x*33.35641,-0.0001*np.ones(len(x)),c='white',linewidth=0,label='')
+    ax1.set_xlim(-1*33.35641,25*33.35641)
+    ax.set_xlim(left=-1,right=25)
+    
+    omega0 = params[0]
+    gamma = params[2]
+    y_max = np.max(lorentzian(x,*params))
+    if not(np.isnan(y_max)): #exclude acoustic at Gamma
+        ax.text(omega0+gamma, y_max/2, 'width='+str(np.round(gamma,2)))
+        ax.axvline(x=omega0, linestyle=':', color='black')
+        #vline1 = ax.plot(np.repeat(omega0,100),np.linspace(0,y_max/2,100),':' ,c='grey')
+        #vline1 = ax.plot(np.repeat(omega0+gamma/2,100),np.linspace(0,y_max/2,100) ,c='orangered')
+        ax.axvspan(omega0-gamma/2, omega0+gamma/2, ymin=0, ymax=1, color='grey', alpha=0.2)
+    graph3, = ax.plot(np.repeat(freq,100),np.linspace(0,y.max(),100), linewidth=1,  c='red', label='freq from dispersion')
+    plt.legend(handles=[   graph3, graph4])
+    plt.tight_layout()
+    fig1.savefig(name_current_dir+'/proj_'+str(k)+'mode'+str(n)+'_lorentzian.pdf')
+# =============================================================================
+
     plt.close(fig)
-#    plt.show()
+    plt.close(fig1)
     return 
 
 def plot_k2(f, data, data_projected, indexes,freqs, max_Z, branches,  freq_res, title=''):
