@@ -7,6 +7,7 @@ Created on Fri Jan 24 14:40:14 2020
 """
 
 import numpy as np
+from scipy import signal
 import os, sys
 from decomp import plot, read
 
@@ -38,21 +39,27 @@ for mode in plot_types:
         namedir = plot.create_folder('')
         freq = np.loadtxt('ZS', usecols=0)
         meta = len(freq)
-        for i in range(Nqpoints):
+        for i in range(1):#(Nqpoints):
             to_skip = (1+meta)*i
             ZZ = np.genfromtxt('Zqs',skip_header=to_skip+1, max_rows=meta)
             Z_q = ZZ[:,0]
             Z = ZZ[:,1:]
             to_skip2 = 4*i
             Params = np.genfromtxt('quasiparticles',skip_header=to_skip2+1, max_rows=3)
+            
     
             k_scaled = qpoints_scaled[i]
-            eigvec = eigvecs[i]
+            eigvec = eigvecs_phonopy[i]
             freq_disp = freqs_disp[i]
             print(' Creating plots for k point = ', k_scaled)
             for n in range(tot_atoms_uc*3):
                 params = Params[:,n]
-                plot.save_proj(freq,Z[:,n],Z_q, qpoints_scaled[i], Ruc, eigvec[:,n],freq_disp[n],n,namedir,masses_for_animation, params,max_Z)
+
+                sig, mi = params[-1]/2, freq[int(len(freq)/2)]
+                gaussian = 1/(sig*np.sqrt(2*np.pi)) * np.exp(-.5*((freq-mi)/sig)**2)
+                convolution_lorentzian = signal.fftconvolve(Z[:,n], plot.lorentzian(freq, freq[int(len(freq)/2)], params[1], params[2]), mode='same') / sum( plot.lorentzian(freq, *params))
+                convolution = signal.fftconvolve(Z[:,n],gaussian, mode='same') / sum( gaussian)
+                plot.save_proj(freq,Z[:,n],Z_q, convolution, qpoints_scaled[i], Ruc, eigvec[:,n],freq_disp[n],n,namedir,masses_for_animation, params, max_Z)
     
     
     if(mode==1):
@@ -272,31 +279,56 @@ for mode in plot_types:
                 params = np.genfromtxt('quasiparticles',skip_header=to_skip+1, max_rows=3)
                 omegas  = params[0,:]
                 
+                csi = np.linalg.norm(np.dot(Hk,qpoint))
+                print('csi: ', csi)
+                print()
                 ##==============================================================================
                 ## C11
-                print('===========================')
+                print('# =============================================================================')
                 print('C11')
                 freqs = []
                 eigvecs_acou = eigvec_q[:,0:3]
                 for j in range(0,3):
                     freqs.append(omegas[j])
                     
-                csi = np.linalg.norm(np.dot(Hk,qpoint))
-                print('csi: ', csi)
+                
                 j = -1
                 freq = freqs[j]
                 eigvec = eigvecs_acou[:,j]
                 print('qpoint scaled: ', qpoint)
-                print('qpoint:', np.dot(Hk,qpoint))
+                print('qpoint:', np.round(np.dot(Hk,qpoint),3))
                 print()
-                print('freqs: ', freqs, ' taken ', freq)
-                print('eigenvec:')
+                print('freqs: ', np.round(freqs,3), ' taken ', np.round(freq,3))
+                print('\neigenvec:')
                 print(np.round(eigvec*ampl/np.sqrt(masses_for_animation),2).reshape(np.shape(Ruc)))
-                print('===========================')
+                print('# =============================================================================')
                 print()
                 C11 = rho * (freq/csi)**2 *conv_factor
                 ##==============================================================================
                 
+                # =============================================================================
+                # C44
+                print('# =============================================================================')
+                print('C44-1')
+                freqs = []
+                eigvecs_acou = eigvec_q[:,0:3]
+                for j in range(0,3):
+                    freqs.append(omegas[j])
+                j = 0
+                freq = freqs[j]
+                eigvec = eigvecs_acou[:,j]
+                print('qpoint scaled: ', qpoint)
+                print('qpoint: ',np.round(np.dot(Hk,qpoint),3))
+                print()
+                print(np.round(freqs,3), ' taken ', np.round(freq,3))
+                print('\neigvec:')
+                print(np.round(eigvec*ampl/np.sqrt(masses_for_animation),2))
+                C44_1 = rho * (freq/csi)**2 *conv_factor
+                print('# =============================================================================')
+                print()
+                # =============================================================================
+                
+                
             if(direc_sc.tolist() in dirs_C12_C44 and np.allclose(qpoint_sc_prev,[0,0,0]) or np.allclose(ks_path[i+1],[0,0,0])):
                 params = np.genfromtxt('quasiparticles',skip_header=to_skip+1, max_rows=3)
                 omegas  = params[0,:]
@@ -307,15 +339,15 @@ for mode in plot_types:
                     print('ERROR WARNING: the q point is not [csi, csi, 0] so everything is gonna be wrong')
                 
                 
+                
                 # =============================================================================
                 # C44
-                print('===========================')
-                print('C44')
+                print('# =============================================================================')
+                print('C44-2')
                 freqs = []
                 eigvecs_acou = eigvec_q[:,0:3]
                 for j in range(0,3):
                     freqs.append(omegas[j])
-                #csi = np.linalg.norm(np.dot(hr,qpoint_scaled))
                 j = 1
                 freq = freqs[j]
                 eigvec = eigvecs_acou[:,j]
@@ -323,17 +355,43 @@ for mode in plot_types:
                 print('qpoint:', np.dot(Hk,qpoint))
                 print()
                 print('freqs: ', freqs, ' taken ', freq)
-                print('eigenvec:')
+                print('\neigenvec:')
                 print(np.round(eigvec*ampl/np.sqrt(masses_for_animation),2).reshape(np.shape(Ruc)))
-                print('===========================')
+                print('# =============================================================================')
                 print()
-                C44 = .5* rho * (freq/csi)**2 *conv_factor
-                # =============================================================================
+                C44_2 = .5* rho * (freq/csi)**2 *conv_factor
+                # =============================================================
+                
                 
                 #==============================================================================
                 # C12
-                print('===========================')
-                print('C12')
+                print('# =============================================================================')
+                print('C12-1')
+                freqs = []
+                eigvecs_acou = eigvec_q[:,0:3]
+                for j in range(0,3):
+                    freqs.append(omegas[j])
+                    
+                #csi = np.linalg.norm(np.dot(hr,qpoint_scaled))
+                j = 0
+                freq = freqs[j]
+                eigvec = eigvecs_acou[:,j]
+                print('qpoint scaled: ', qpoint)
+                print('qpoint: ',np.round(np.dot(Hk,qpoint),3))
+                print()
+                print(np.round(freqs,3), ' taken ', np.round(freq,3))
+                print('\neigvec:')
+                print(np.round(eigvec*ampl/np.sqrt(masses_for_animation),2))
+                A = rho * (freq/csi)**2 *conv_factor
+                C12_1 =C11-A  #<- with freqs[0] # A - C11 -2*C44 #
+                print('# =============================================================================')
+                print()
+                #==============================================================================
+                
+                #==============================================================================
+                # C12
+                print('# =============================================================================')
+                print('C12-2')
                 freqs = []
                 eigvecs_acou = eigvec_q[:,0:3]
                 for j in range(0,3):
@@ -349,25 +407,29 @@ for mode in plot_types:
                 print('freqs: ', freqs, ' taken ', freq)
                 print('eigenvec:')
                 print(np.round(eigvec*ampl/np.sqrt(masses_for_animation),2).reshape(np.shape(Ruc)))
-                print('===========================')
+                print('# =============================================================================')
                 print()
                 A = rho * (freq/csi)**2 *conv_factor
-                C12 = A - C11 -2*C44 #C11-A  <- with freqs[0]
+                C12_2 = A - C11 -2*C44_1 #C11-A  #<- with freqs[0] #
+                C12_2_2 = A - C11 -2*C44_2
                 #==============================================================================
                 
                 print()
                 print('Elastic constants')
                 print('C11 = ', np.round(C11,2), 'GPa')
-                print('C44 = ', np.round(C44,2), 'GPa')
-                print('C12 = ', np.round(C12,2), 'GPa')
+                print('C44 using [100] = ', np.round(C44_1,2), 'GPa')
+                print('C44 using [110] = ', np.round(C44_2,2), 'GPa')
+                print('C12 using eq 1 = ', np.round(C12_1,2), 'GPa')
+                print('C12 using eq 2 (C44[100])= ', np.round(C12_2,2), 'GPa')
+                print('C12 using eq 2 (C44[110])= ', np.round(C12_2_2,2), 'GPa')
                 
                 print()
                 print('Engineering elastic constants')
-                ni = C12/(C11+C12)
+                ni = C12_2_2/(C11+C12_2_2)
                 E = C11*(1+ni)*(1-2*ni)/(1-ni)
                 print('E = ', np.round(E,2), 'GPa')
                 print('ni = ', np.round(ni,2))
-                print('G = ', np.round(C44,2), 'GPa')
+                print('G = ', np.round(C44_2,2), 'GPa')
         
         
 
